@@ -1,48 +1,56 @@
-/*===========================================================================*\
+/* ========================================================================= *
  *                                                                           *
  *                               OpenMesh                                    *
- *      Copyright (C) 2001-2014 by Computer Graphics Group, RWTH Aachen      *
- *                           www.openmesh.org                                *
+ *           Copyright (c) 2001-2025, RWTH-Aachen University                 *
+ *           Department of Computer Graphics and Multimedia                  *
+ *                          All rights reserved.                             *
+ *                            www.openmesh.org                               *
  *                                                                           *
- *---------------------------------------------------------------------------* 
- *  This file is part of OpenMesh.                                           *
+ *---------------------------------------------------------------------------*
+ * This file is part of OpenMesh.                                            *
+ *---------------------------------------------------------------------------*
  *                                                                           *
- *  OpenMesh is free software: you can redistribute it and/or modify         * 
- *  it under the terms of the GNU Lesser General Public License as           *
- *  published by the Free Software Foundation, either version 3 of           *
- *  the License, or (at your option) any later version with the              *
- *  following exceptions:                                                    *
+ * Redistribution and use in source and binary forms, with or without        *
+ * modification, are permitted provided that the following conditions        *
+ * are met:                                                                  *
  *                                                                           *
- *  If other files instantiate templates or use macros                       *
- *  or inline functions from this file, or you compile this file and         *
- *  link it with other files to produce an executable, this file does        *
- *  not by itself cause the resulting executable to be covered by the        *
- *  GNU Lesser General Public License. This exception does not however       *
- *  invalidate any other reasons why the executable file might be            *
- *  covered by the GNU Lesser General Public License.                        *
+ * 1. Redistributions of source code must retain the above copyright notice, *
+ *    this list of conditions and the following disclaimer.                  *
  *                                                                           *
- *  OpenMesh is distributed in the hope that it will be useful,              *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of           *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
- *  GNU Lesser General Public License for more details.                      *
+ * 2. Redistributions in binary form must reproduce the above copyright      *
+ *    notice, this list of conditions and the following disclaimer in the    *
+ *    documentation and/or other materials provided with the distribution.   *
  *                                                                           *
- *  You should have received a copy of the GNU LesserGeneral Public          *
- *  License along with OpenMesh.  If not,                                    *
- *  see <http://www.gnu.org/licenses/>.                                      *
+ * 3. Neither the name of the copyright holder nor the names of its          *
+ *    contributors may be used to endorse or promote products derived from   *
+ *    this software without specific prior written permission.               *
  *                                                                           *
-\*===========================================================================*/ 
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS       *
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED *
+ * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A           *
+ * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER *
+ * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,  *
+ * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,       *
+ * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR        *
+ * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF    *
+ * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING      *
+ * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS        *
+ * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.              *
+ *                                                                           *
+ * ========================================================================= */
+
 
-/*===========================================================================*\
- *                                                                           *             
- *   $Revision: 990 $                                                         *
- *   $Date: 2014-02-05 10:01:07 +0100 (Mi, 05 Feb 2014) $                   *
- *                                                                           *
-\*===========================================================================*/
 
 #include <OpenMesh/Core/Mesh/BaseKernel.hh>
+#include <iostream>
+
 namespace OpenMesh
 {
 
+void BaseKernel::property_stats() const
+{
+  property_stats(std::clog);
+}
 void BaseKernel::property_stats(std::ostream& _ostr) const
 {
   const PropertyContainer::Properties& vps = vprops_.properties();
@@ -56,27 +64,27 @@ void BaseKernel::property_stats(std::ostream& _ostr) const
   _ostr << vprops_.size() << " vprops:\n";
   for (it=vps.begin(); it!=vps.end(); ++it)
   {
-    *it == NULL ? (void)(_ostr << "[deleted]" << "\n") : (*it)->stats(_ostr);
+    *it == nullptr ? (void)(_ostr << "[deleted]" << "\n") : (*it)->stats(_ostr);
   }
   _ostr << hprops_.size() << " hprops:\n";
   for (it=hps.begin(); it!=hps.end(); ++it)
   {
-    *it == NULL ? (void)(_ostr << "[deleted]" << "\n") : (*it)->stats(_ostr);
+    *it == nullptr ? (void)(_ostr << "[deleted]" << "\n") : (*it)->stats(_ostr);
   }
   _ostr << eprops_.size() << " eprops:\n";
   for (it=eps.begin(); it!=eps.end(); ++it)
   {
-    *it == NULL ? (void)(_ostr << "[deleted]" << "\n") : (*it)->stats(_ostr);
+    *it == nullptr ? (void)(_ostr << "[deleted]" << "\n") : (*it)->stats(_ostr);
   }
   _ostr << fprops_.size() << " fprops:\n";
   for (it=fps.begin(); it!=fps.end(); ++it)
   {
-    *it == NULL ? (void)(_ostr << "[deleted]" << "\n") : (*it)->stats(_ostr);
+    *it == nullptr ? (void)(_ostr << "[deleted]" << "\n") : (*it)->stats(_ostr);
   }
   _ostr << mprops_.size() << " mprops:\n";
   for (it=mps.begin(); it!=mps.end(); ++it)
   {
-    *it == NULL ? (void)(_ostr << "[deleted]" << "\n") : (*it)->stats(_ostr);
+    *it == nullptr ? (void)(_ostr << "[deleted]" << "\n") : (*it)->stats(_ostr);
   }
 }
 
@@ -89,7 +97,7 @@ void BaseKernel::vprop_stats( std::string& _string ) const
   PropertyContainer::Properties::const_iterator it;
   const PropertyContainer::Properties& vps = vprops_.properties();
   for (it=vps.begin(); it!=vps.end(); ++it)
-    if ( *it == NULL )
+    if ( *it == nullptr )
       _string += "[deleted] \n";
     else {
       _string += (*it)->name();
@@ -105,7 +113,7 @@ void BaseKernel::hprop_stats( std::string& _string ) const
   PropertyContainer::Properties::const_iterator it;
   const PropertyContainer::Properties& hps = hprops_.properties();
   for (it=hps.begin(); it!=hps.end(); ++it)
-    if ( *it == NULL )
+    if ( *it == nullptr )
       _string += "[deleted] \n";
     else {
       _string += (*it)->name();
@@ -121,7 +129,7 @@ void BaseKernel::eprop_stats( std::string& _string ) const
   PropertyContainer::Properties::const_iterator it;
   const PropertyContainer::Properties& eps = eprops_.properties();
   for (it=eps.begin(); it!=eps.end(); ++it)
-    if ( *it == NULL )
+    if ( *it == nullptr )
       _string += "[deleted] \n";
     else {
       _string += (*it)->name();
@@ -136,7 +144,7 @@ void BaseKernel::fprop_stats( std::string& _string ) const
   PropertyContainer::Properties::const_iterator it;
   const PropertyContainer::Properties& fps = fprops_.properties();
   for (it=fps.begin(); it!=fps.end(); ++it)
-    if ( *it == NULL )
+    if ( *it == nullptr )
       _string += "[deleted] \n";
     else {
       _string += (*it)->name();
@@ -152,7 +160,7 @@ void BaseKernel::mprop_stats( std::string& _string ) const
   PropertyContainer::Properties::const_iterator it;
   const PropertyContainer::Properties& mps = mprops_.properties();
   for (it=mps.begin(); it!=mps.end(); ++it)
-    if ( *it == NULL )
+    if ( *it == nullptr )
       _string += "[deleted] \n";
     else {
       _string += (*it)->name();
@@ -161,45 +169,64 @@ void BaseKernel::mprop_stats( std::string& _string ) const
 
 }
 
+void BaseKernel::vprop_stats() const
+{
+  vprop_stats(std::clog);
+}
 void BaseKernel::vprop_stats(std::ostream& _ostr ) const
 {
   PropertyContainer::Properties::const_iterator it;
   const PropertyContainer::Properties& vps = vprops_.properties();
   for (it=vps.begin(); it!=vps.end(); ++it)
-    *it == NULL ? (void)(_ostr << "[deleted]" << "\n") : (*it)->stats(_ostr);
+    *it == nullptr ? (void)(_ostr << "[deleted]" << "\n") : (*it)->stats(_ostr);
 
 }
-
+void BaseKernel::hprop_stats() const
+{
+  hprop_stats(std::clog);
+}
 void BaseKernel::hprop_stats(std::ostream& _ostr ) const
 {
   PropertyContainer::Properties::const_iterator it;
   const PropertyContainer::Properties& hps = hprops_.properties();
   for (it=hps.begin(); it!=hps.end(); ++it)
-    *it == NULL ? (void)(_ostr << "[deleted]" << "\n") : (*it)->stats(_ostr);
+    *it == nullptr ? (void)(_ostr << "[deleted]" << "\n") : (*it)->stats(_ostr);
 
 }
+void BaseKernel::eprop_stats() const
+{
+  eprop_stats(std::clog);
+}
 void BaseKernel::eprop_stats(std::ostream& _ostr ) const
 {
   PropertyContainer::Properties::const_iterator it;
   const PropertyContainer::Properties& eps = eprops_.properties();
   for (it=eps.begin(); it!=eps.end(); ++it)
-    *it == NULL ? (void)(_ostr << "[deleted]" << "\n") : (*it)->stats(_ostr);
+    *it == nullptr ? (void)(_ostr << "[deleted]" << "\n") : (*it)->stats(_ostr);
 
 }
+void BaseKernel::fprop_stats() const
+{
+  fprop_stats(std::clog);
+}
 void BaseKernel::fprop_stats(std::ostream& _ostr ) const
 {
   PropertyContainer::Properties::const_iterator it;
   const PropertyContainer::Properties& fps = fprops_.properties();
   for (it=fps.begin(); it!=fps.end(); ++it)
-    *it == NULL ? (void)(_ostr << "[deleted]" << "\n") : (*it)->stats(_ostr);
+    *it == nullptr ? (void)(_ostr << "[deleted]" << "\n") : (*it)->stats(_ostr);
 
 }
+void BaseKernel::mprop_stats() const
+{
+  mprop_stats(std::clog);
+}
 void BaseKernel::mprop_stats(std::ostream& _ostr ) const
 {
   PropertyContainer::Properties::const_iterator it;
   const PropertyContainer::Properties& mps = mprops_.properties();
   for (it=mps.begin(); it!=mps.end(); ++it)
-    *it == NULL ? (void)(_ostr << "[deleted]" << "\n") : (*it)->stats(_ostr);
+    *it == nullptr ? (void)(_ostr << "[deleted]" << "\n") : (*it)->stats(_ostr);
 
 }
 
